/* vi:set ts=8 sts=0 sw=8:
 * $Id: debug.c,v 1.2 1999/01/18 19:43:21 kahn Exp kahn $
 *
 * Copyright (C) 1998 Andy C. Kahn <kahn@zk3.dec.com>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include <stdio.h>
#include "main.h"
#include "debug.h"

#ifdef APP_DEBUG

long dbg_flags = 0;

/* eventually, there may be more debugging routines in here */
/* for now, the printf macros in debug.h are enough */

#endif	/* APP_DEBUG */

/* the end */
